<?xml version="1.0"?> 

<!DOCTYPE xsl:stylesheet [
	<!ENTITY copy "&#169;">
	<!ENTITY nbsp "&#160;">
	<!ENTITY mdash "&#8212;">
]>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">


<!-- ======================================================================= -->
<!--    G L O B A L S                                                        -->
<!-- ======================================================================= -->

<!-- load site configuration -->
<xsl:variable name="config" select="document($lt_site_master_document)" />
<xsl:variable name="translations" select="document($lt_translations_document)" />

<!-- author -->
<xsl:variable name="author_name" select="$config/site/feed/author/name" />
<xsl:variable name="author_email" select="$config/site/feed/author/email" />
<xsl:variable name="author_web" select="$config/site/feed/author/web" />

<!-- generator -->
<xsl:variable name="generator_name" select="$config/site/feed/generator/name" />
<xsl:variable name="generator_url" select="$config/site/feed/generator/link[@id='product']" />
<xsl:variable name="generator_version" select="$config/site/feed/generator/version" />
<xsl:variable name="generator_fullName" select="concat ($generator_name, ' ', $generator_version)" />

<!-- page -->
<xsl:variable name="page_content" select="/page/@content" />
<xsl:variable name="page_name" select="/page/@name" />

<!-- feed -->
<xsl:variable name="feed_copyright" select="$config/site/feed/copyright" />
<xsl:variable name="feed_description" select="$config/site/feed/description" />
<xsl:variable name="feed_lang">
	<xsl:variable name="choosenLang" select="$config/site/feed/language" />
	<xsl:choose>
		<xsl:when test="$translations/translations/languages/lang[@lang=$choosenLang]">
			<xsl:value-of select="$choosenLang" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>en</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="feed_subTitle">
	<xsl:value-of select="$config/site/feed/subTitle" />
</xsl:variable>
<xsl:variable name="feed_title">
	<xsl:value-of select="$config/site/feed/title" />
</xsl:variable>

<!-- layout -->
<xsl:variable name="layout_theme">
	<xsl:value-of select="$config/site/feed/layout/theme" />
</xsl:variable>

<!-- links -->
<xsl:variable name="link_css">
	<!--
	<xsl:choose>
		<xsl:when test="$layout_theme != ''">
			<xsl:value-of select="$config/site/feed/links/link[@id='rootFolder']" /><xsl:text>/styles/</xsl:text>
			<xsl:value-of select="$layout_theme" /><xsl:text>.css</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$config/site/feed/links/link[@id='rootFolder']" /><xsl:text>/styles/main.css</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	-->
	<xsl:value-of select="$config/site/feed/links/link[@id='rootFolder']" /><xsl:text>/styles/main.css</xsl:text>
</xsl:variable>
<xsl:variable name="link_mainAtom" select="$config/site/feed/links/link[@id='mainAtom']" />
<xsl:variable name="link_mainIndex" select="$config/site/feed/links/link[@id='mainIndex']" />
<xsl:variable name="link_mainRss" select="$config/site/feed/links/link[@id='mainRss']" />
<xsl:variable name="link_rss092" select="$config/site/feed/links/link[@id='rss092']" />
<xsl:variable name="link_rss1" select="$config/site/feed/links/link[@id='rss1']" />
<xsl:variable name="link_rss2" select="$config/site/feed/links/link[@id='rss2']" />
<xsl:variable name="link_rootFolder" select="$config/site/feed/links/link[@id='rootFolder']" />
<xsl:variable name="link_rootPage" select="$config/site/feed/links/link[@id='rootPage']" />

<!-- images -->
<xsl:variable name="image_folder">
	<xsl:value-of select="$link_rootFolder" /><xsl:text>/images</xsl:text>
</xsl:variable>
<xsl:variable name="image_mainRss">
	<xsl:value-of select="$image_folder" /><xsl:text>/rss_blue.png</xsl:text>
</xsl:variable>
<xsl:variable name="image_rss092">
	<xsl:value-of select="$image_folder" /><xsl:text>/rss092.gif</xsl:text>
</xsl:variable>
<xsl:variable name="image_rss1">
	<xsl:value-of select="$image_folder" /><xsl:text>/rss1.gif</xsl:text>
</xsl:variable>
<xsl:variable name="image_rss2">
	<xsl:value-of select="$image_folder" /><xsl:text>/rss2.gif</xsl:text>
</xsl:variable>
<xsl:variable name="image_mainAtom">
	<xsl:value-of select="$image_folder" /><xsl:text>/atom.gif</xsl:text>
</xsl:variable>
<xsl:variable name="image_shortcutIcon">
	<xsl:value-of select="$image_folder" /><xsl:text>/shortcut.ico</xsl:text>
</xsl:variable>

<!-- translations -->
<xsl:variable name="translation_author_name" select="$translations/translations/author/name/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_author_email" select="$translations/translations/author/email/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_author_web" select="$translations/translations/author/web/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_block_at" select="$translations/translations/block/at/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_page_about" select="$translations/translations/page/about/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_page_archives" select="$translations/translations/page/archives/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_page_categories" select="$translations/translations/page/categories/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_page_contact" select="$translations/translations/page/contact/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_page_entries" select="$translations/translations/page/entries/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_page_mainIndex" select="$translations/translations/page/mainIndex/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_page_poweredBy" select="$translations/translations/page/poweredBy/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_toolTip_goToArchive" select="$translations/translations/toolTip/goToArchive/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_toolTip_goToCategory" select="$translations/translations/toolTip/goToCategory/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_toolTip_goToHomepage" select="$translations/translations/toolTip/goToHomepage/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_toolTip_sendMeAnEmail" select="$translations/translations/toolTip/sendMeAnEmail/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_toolTip_subscripeToThisFeed" select="$translations/translations/toolTip/subscribeToThisFeed/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_toolTip_viewEntry" select="$translations/translations/toolTip/viewEntry/translation[@lang = $feed_lang]" />
<xsl:variable name="translation_toolTip_visitMyWebsite" select="$translations/translations/toolTip/visitMyWebsite/translation[@lang = $feed_lang]" />



<!-- ======================================================================= -->
<!--    T E M P L A T E S                                                    -->
<!-- ======================================================================= -->


<!-- ==  a r c h i v e s  ================================================== -->

<xsl:template match="archive">
	<xsl:variable name="title">
		<xsl:value-of select="$translation_toolTip_goToArchive" /><xsl:text> </xsl:text><xsl:value-of select="." />
	</xsl:variable>
	<li><a href="{@href}" title="{$title}"><xsl:value-of disable-output-escaping="yes" select="." /></a></li>
	<!--<li><a href="{@href}"><xsl:value-of select="." /></a> (<xsl:value-of select="@entriesCount" />)</li>-->
</xsl:template>



<!-- ==  b o d y  ========================================================== -->

<xsl:template name="body">
	<xsl:if test="$page_content = 'index'">
		<xsl:if test="$config/*/categories/category">
			<h3 class="first"><xsl:value-of select="$translation_page_categories" /></h3>
			<ul>
				<xsl:apply-templates select="$config/*/categories/category" mode="multiline" />
			</ul>
		</xsl:if>
		
		<h3><xsl:value-of select="$translation_page_archives" /></h3>
		<ul>
			<xsl:apply-templates select="$config/*/archives/archive"/>
		</ul>
	</xsl:if>
	
	<xsl:if test="$page_content = 'archive'">
		<h2><xsl:value-of select="$page_name" /></h2>
	</xsl:if>
	<xsl:if test="$page_content = 'category'">
		<h2><xsl:value-of select="$page_name" /></h2>
	</xsl:if>
	
	<xsl:choose>
		<xsl:when test="$page_content = 'index'">
			<h3><xsl:value-of select="$translation_page_entries" /></h3>
			<xsl:apply-templates select="item" mode="index" />
		</xsl:when>
		<xsl:otherwise>
			<dl id="itemList">
				<xsl:apply-templates select="item"/>
			</dl>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>



<!-- ==  c a t e g o r i e s  ============================================== -->

<xsl:template match="category" mode="multiline">
	<xsl:variable name="title">
		<xsl:value-of select="$translation_toolTip_goToCategory" /><xsl:text> </xsl:text><xsl:value-of disable-output-escaping="yes" select="." />
	</xsl:variable>
	<li><a href="{@href}" title="{$title}"><xsl:value-of disable-output-escaping="yes" select="." /></a></li>
</xsl:template>

<xsl:template match="category" mode="singleline">
	<xsl:variable name="title">
		<xsl:value-of select="$translation_toolTip_goToCategory" /><xsl:text> </xsl:text><xsl:value-of disable-output-escaping="yes" select="." />
	</xsl:variable>
	<a href="{@href}" title="{$title}"><xsl:value-of disable-output-escaping="yes" select="." /></a>
	<xsl:if test="position() != last()">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>

<xsl:template match="category" mode="singlelineSimple">
	<xsl:variable name="title">
		<xsl:value-of select="$translation_toolTip_goToCategory" /><xsl:text> </xsl:text><xsl:value-of disable-output-escaping="yes" select="." />
	</xsl:variable>
	<a href="{@href}" title="{$title}" class="simple"><xsl:value-of disable-output-escaping="yes" select="." /></a>
	<xsl:if test="position() != last()">
		<xsl:text>, </xsl:text>
	</xsl:if>
</xsl:template>



<!-- ==  c o p y r i g h t  ================================================ -->

<xsl:template name="copyright">
	<xsl:if test="$feed_copyright">
		<p><xsl:value-of disable-output-escaping="yes" select="$feed_copyright" /></p>
	</xsl:if>
</xsl:template>



<!-- ==  h e a d e r  ====================================================== -->

<xsl:template name="header">
	<a href="{$link_rootPage}" title="{$translation_toolTip_goToHomepage}"><xsl:value-of disable-output-escaping="yes" select="$feed_title" /></a>
	<div id="subHeader"><xsl:value-of select="$feed_subTitle" /></div>
</xsl:template>



<!-- ==  i t e m  ========================================================== -->

<xsl:template match="item">
	<xsl:choose>
		<xsl:when test="position() = 1">
			<dt class="first"><a href="{link}" title="{$translation_toolTip_viewEntry}"><xsl:value-of disable-output-escaping="yes" select="title" /></a></dt>
		</xsl:when>
		<xsl:otherwise>
			<dt><a href="{link}" title="{$translation_toolTip_viewEntry}"><xsl:value-of disable-output-escaping="yes" select="title" /></a></dt>
		</xsl:otherwise>
	</xsl:choose>
   	<dd>
     	<div class="date"><xsl:value-of disable-output-escaping="yes" select="created/@date" /></div>
     	<div class="text">
			<xsl:choose>
				<xsl:when test="$page_content = 'entry'">
					<xsl:value-of disable-output-escaping="yes" select="text" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of disable-output-escaping="yes" select="abstract" />
				</xsl:otherwise>
			</xsl:choose>
     	</div>
     	<div class="details">
       		<a href="{link}" title="{$translation_toolTip_viewEntry}" class="simple"><xsl:value-of disable-output-escaping="yes" select="$author_name" />
       			<xsl:text> </xsl:text>
       			<xsl:value-of select="$translation_block_at" />
       			<xsl:text> </xsl:text>
       			<xsl:value-of select="created/@time" />
       		</a>
       		<xsl:if test="category">
				<xsl:text> | </xsl:text><xsl:value-of select="$translation_page_categories" /><xsl:text>: </xsl:text>
				<xsl:apply-templates select="category" mode="singleline" />
			</xsl:if>
     	</div>
	</dd>
</xsl:template>

<xsl:template match="item" mode="index">
	<xsl:value-of select="substring (created/@dateTime, 1, 7)" />
	<xsl:text> - </xsl:text>
	<a href="{link}" title="{$translation_toolTip_viewEntry}"><xsl:value-of disable-output-escaping="yes" select="title" /></a>
	<xsl:if test="category">
		<xsl:text> - </xsl:text>
		<xsl:apply-templates select="category" mode="singlelineSimple" />
	</xsl:if>
	<br />
</xsl:template>



<!-- ==  m e t a  ========================================================== -->

<xsl:template name="meta">
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
	<meta name="generator" content="{$generator_fullName}" />
	<meta name="description" content="{$feed_description}" />

	<title><xsl:value-of disable-output-escaping="yes" select="$feed_title" /></title>
	
	<link rel="stylesheet" href="{$link_css}" />
	<link rel="alternate" type="application/rss+xml" title="{$feed_title}" href="{$link_mainRss}" />
	<!-- <link rel="Shortcut Icon" type="image/x-icon" href="{$image_shortcutIcon}" /> -->
</xsl:template>



<!-- ==  s i d e b a r  ==================================================== -->

<xsl:template name="sidebar">
	<dl id="toc">
	
	<!-- about me: -->
	<xsl:if test="$feed_description != ''">
		<dt class="first"><xsl:value-of select="$translation_page_about" /></dt>
		<dd>
			<xsl:value-of select="$feed_description" />
		</dd>
	</xsl:if>
   
	<!-- categories: -->
	<xsl:if test="$page_content != 'entry' and $page_content != 'index' and $config/*/categories/category">
		<dt><xsl:value-of select="$translation_page_categories" /></dt>
		<dd>
			<ul>
				<xsl:variable name="limit" select="$config/*/categories/@showOnPage" />
				<xsl:apply-templates select="$config/*/categories/category[position() &lt;= $limit]" mode="multiline" />
			</ul>
		</dd>
	</xsl:if>
	
	<!-- archives: -->
	<xsl:if test="$page_content != 'index'">
		<dt><xsl:value-of select="$translation_page_archives" /></dt>
		<dd>
			<ul>
				<li><a href="{$link_mainIndex}"><xsl:value-of select="$translation_page_mainIndex" /></a></li>
				<xsl:if test="$page_content != 'entry'">
					<xsl:variable name="limit" select="$config/*/archives/@showOnPage" />
					<xsl:apply-templates select="$config/*/archives/archive[position() &lt;= $limit]"/>
				</xsl:if>
			</ul>
		</dd>
	</xsl:if>

	<!-- contact: -->
	<xsl:if test="$author_email != '' or $author_web != ''">		
		<dt><xsl:value-of select="$translation_page_contact" /></dt>
		<dd>
			<ul>
				<xsl:if test="$author_email != ''">
					<xsl:variable name='mailtoLink'>
						<xsl:text>mailto:</xsl:text>
						<xsl:value-of select="$author_email" />
						<xsl:text>?subject=Your blog '</xsl:text>
						<xsl:value-of select="$feed_title" />
						<xsl:text>'</xsl:text>
					</xsl:variable>
					<li><a href="{$mailtoLink}" title="{$translation_toolTip_sendMeAnEmail}"><xsl:value-of select="$translation_author_email" /></a></li>
				</xsl:if>
				<xsl:if test="$author_web != ''">
					<li><a href="{$author_web}" title="{$translation_toolTip_visitMyWebsite}"><xsl:value-of select="$translation_author_web" /></a></li>
				</xsl:if>
			</ul>
		</dd>
	</xsl:if>

	<!-- powered: -->
	<dt><xsl:value-of select="$translation_page_poweredBy" /></dt>
	<dd>
		<ul>
			<li><a href="{$generator_url}"><xsl:value-of select="$generator_fullName" /></a></li>
		</ul>
	</dd>
	
	<!-- syndicate: -->
	<dt></dt>
	<dd>
		<xsl:if test="$link_mainRss">
			<a href="{$link_mainRss}" title="{$translation_toolTip_subscripeToThisFeed}"><img src="{$image_mainRss}" width="41" height="25" alt="main rss feed" class="plain" /></a><br />
		</xsl:if>
	</dd>

	</dl><!-- sidebar -->
</xsl:template>

</xsl:stylesheet>